@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: trifecta
 version: 1.5.2
-id: trifecta-1.5.2-96179b3dc56b0523b4210016cc24d8aa
-key: trife_867UHYR4huK1wToRS1hYJ7
+id: trifecta-1.5.2-973d811177414a3af9c8805a938490ba
+key: trife_3zDZsKuAETIDT0guuOGtCJ
 license: BSD3
 copyright: Copyright (C) 2010-2014 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -27,31 +27,31 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/trifecta-1.5.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/trifecta-1.5.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/trifecta-1.5.2
-hs-libraries: HStrifecta-1.5.2-867UHYR4huK1wToRS1hYJ7
+hs-libraries: HStrifecta-1.5.2-3zDZsKuAETIDT0guuOGtCJ
 depends:
     ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
     ansi-wl-pprint-0.6.7.3-28ee0530b985e8f17809a30013a735ed
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
-    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
-    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
+    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
+    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
+    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    charset-0.3.7.1-07fa1295548c21364abbf3188fa2df38
-    comonad-5-a91321d086a2de4a04a44d60c347669e
+    charset-0.3.7.1-eb9c9b19f9448bfb51c91765226aa73d
+    comonad-5-e98e7adc8875accf64a86529d9aeae51
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     fingertree-0.1.1.0-2b52886bad6677cc2ba4bb73e01240b3
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
-    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
-    lens-4.13.2.1-7da1232efa9fbb46f4651315f7427146
+    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
+    lens-4.13.2.1-3b086cb541bae44e8089b135a290af93
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    parsers-0.12.3-39fdea4c999d2dce5f1305b594de4161
-    profunctors-5.2-dcebd670a79351324a9f8d71a72c88e3
-    reducers-3.12.1-9c0679f8e3a7104b42907174b9bc86fd
-    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
+    parsers-0.12.3-249c3658e44c9e939031fdd5e1ad8519
+    profunctors-5.2-aaf86384a4db0133740cbda80ff5e59a
+    reducers-3.12.1-643a8857fe1ff69e9322fcb3ed491f08
+    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
+    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
 haddock-interfaces: /usr/share/doc/haskell-trifecta/html/trifecta.haddock
 haddock-html: /usr/share/doc/haskell-trifecta/html
